@@ -52,6 +52,11 @@ class MagicSettings(BaseSettings):
     firebase_project_id: str = None
     cloud_function_location: str = None
 
+    use_doorman_redis: bool = False
+    doorman_redis_endpoint: str = None
+    doorman_redis_port: int = None
+    doorman_redis_password: str = None
+
     # for twilio
     twilio_account_sid: str = None
     twilio_auth_token: str = None
